@@ -9,6 +9,13 @@
  */
 
 #include <ostream>
+#include <sys/file.h>
+#ifdef __linux__ 
+#include <linux/errno.h>
+#ifndef ENOTSUPP
+#define ENOTSUPP 524
+#endif
+#endif
 
 #include "eckit/exception/Exceptions.h"
 #include "eckit/io/FDataSync.h"
@@ -652,6 +659,65 @@ void BTree<K, V, S, L>::unlock() {
     L::lockRange(file_.fileno(), 0, 0, F_SETLK, F_UNLCK);
 }
 
+template <class K, class V, int S, class L>
+void BTree<K, V, S, L>::flock() {
+
+    if (::flock(file_.fileno(), readOnly_ ? LOCK_EX : LOCK_SH) < 0)
+    {
+        bool skip = false;
+        #ifdef ENOTSUP
+            if (errno == ENOTSUP) {
+                skip = true;
+            }
+        #endif
+        #ifdef ENOTSUPP
+            if (errno == ENOTSUPP) {
+                skip = true;
+            }
+        #endif
+        #ifdef EOPNOTSUPP
+            if (errno == EOPNOTSUPP) {
+                skip = true;
+            }
+        #endif
+        if (!skip) {
+            std::stringstream ss;
+            ss << "Error " << Log::syserr << " locking " << path_;
+            throw eckit::UserError(ss.str(), Here());
+        }
+    }
+}
+
+template <class K, class V, int S, class L>
+void BTree<K, V, S, L>::funlock() {
+
+    if (::flock(file_.fileno(), LOCK_UN) < 0)
+    {
+        bool skip = false;
+        #ifdef ENOTSUP
+            if (errno == ENOTSUP) {
+                skip = true;
+            }
+        #endif
+        #ifdef ENOTSUPP
+            if (errno == ENOTSUPP) {
+                skip = true;
+            }
+        #endif
+        #ifdef EOPNOTSUPP
+            if (errno == EOPNOTSUPP) {
+                skip = true;
+            }
+        #endif
+        if (!skip) {
+            std::stringstream ss;
+            ss << "Error " << Log::syserr << " unlocking " << path_;
+            throw eckit::UserError(ss.str(), Here());
+        }
+    }
+}
+
+
 //----------------------------------------------------------------------------------------------------------------------
 
 }  // namespace eckit
