@@ -145,6 +145,10 @@ public:  // methods
     /// @return true (local paths are always available)
     bool available() const;
 
+    /// Check if path is offsite
+    /// @return true (local paths are always available)
+    bool offsite() const;
+
     /// Touch the path. The path leading to it is created if it does not exist.
     void touch() const;
 
