@@ -45,6 +45,7 @@ public:  // methods
     /// Removes an entry from the registry
     /// @pre Must exist
     void deregister(const std::string& name) {
+        if(LibEcKit::instance().dontDeregisterFactories()) return;
         AutoLock<Mutex> lockme(mutex_);
         ASSERT(map_.find(name) != map_.end());
         map_.erase(name);
@@ -103,7 +104,8 @@ private:  // members
 
 //----------------------------------------------------------------------------------------------------------------------
 
-URIManager::URIManager(const std::string& name) : name_(name) {
+URIManager::URIManager(const std::string& name) :
+    name_(name) {
     URIManagerRegistry::instance().enregister(name, this);
 }
 
@@ -154,7 +156,8 @@ class LocalFilePartManager : public URIManager {
     PathName path(const URI& uri) const override { return PathName("local", uri.name()); }
 
 public:
-    LocalFilePartManager(const std::string& name) : URIManager(name) {}
+    LocalFilePartManager(const std::string& name) :
+        URIManager(name) {}
 };
 
 //----------------------------------------------------------------------------------------------------------------------
@@ -194,7 +197,8 @@ class HttpURIManager : public URIManager {
     }
 
 public:
-    HttpURIManager(const std::string& name) : URIManager(name) {}
+    HttpURIManager(const std::string& name) :
+        URIManager(name) {}
 };
 
 //----------------------------------------------------------------------------------------------------------------------
