@@ -20,13 +20,15 @@
 #include "eckit/log/JSON.h"
 #include "eckit/memory/Zero.h"
 #include "eckit/thread/AutoLock.h"
-
-//----------------------------------------------------------------------------------------------------------------------
+#include "eckit/utils/Clock.h"
+#include "eckit/config/EtcTable.h"
 
 namespace eckit {
 
 //----------------------------------------------------------------------------------------------------------------------
 
+static const constexpr int MAX_NODE_ATTRIBUTES = 16;
+
 class ClusterNodeEntry {
     bool active_;
     time_t lastSeen_;
@@ -34,17 +36,40 @@ class ClusterNodeEntry {
     char node_[256];
     char type_[256];
     char host_[256];
+    int nattrs_;
+    char attributes_[MAX_NODE_ATTRIBUTES][256];
     int port_;
 
-public:
-    ClusterNodeEntry(const std::string& node, const std::string& type, const std::string& host, int port) :
-        active_(true), lastSeen_(::time(0)), offLine_(false), port_(port) {
+    ClusterNodeEntry(const std::string& node, const std::string& type, const std::string& host, int port, const std::set<std::string>& attributes) :
+        active_(true), lastSeen_(Clock::now()), offLine_(false), port_(port) {
         zero(node_);
         strncpy(node_, node.c_str(), sizeof(node_) - 1);
         zero(type_);
         strncpy(type_, type.c_str(), sizeof(type_) - 1);
         zero(host_);
         strncpy(host_, host.c_str(), sizeof(host_) - 1);
+        ASSERT(attributes.size() <= MAX_NODE_ATTRIBUTES);
+        zero(attributes_);
+        nattrs_ = 0;
+        for (const auto& a : attributes) {
+            strncpy(attributes_[nattrs_++], a.c_str(), sizeof(attributes_[0])-1);
+        }
+    }
+
+public:
+
+    ClusterNodeEntry(const NodeInfo& info) :
+        ClusterNodeEntry(info.node(), info.name(), info.host(), info.port(), info.attributes()) {}
+
+    NodeInfo asNodeInfo() const {
+        NodeInfo info;
+        info.name(type());
+        info.node(node());
+        info.host(host());
+        info.port(port());
+        info.active(!offLine());
+        info.attributes(attributes());
+        return info;
     }
 
     bool operator<(const ClusterNodeEntry& other) const {
@@ -62,6 +87,10 @@ public:
         s << node_;
         s << type_;
         s << host_;
+        s << nattrs_;
+        for (int i = 0; i < nattrs_; ++i) {
+            s << attributes_[i];
+        }
         s << port_;
     }
 
@@ -73,6 +102,12 @@ public:
         s << "node" << node_;
         s << "type" << type_;
         s << "host" << host_;
+        s << "attributes";
+        s.startList();
+        for (int i = 0; i < nattrs_; ++i) {
+            s << attributes_[i];
+        }
+        s.endList();
         s << "port" << port_;
         s.endObject();
     }
@@ -98,6 +133,14 @@ public:
         zero(host_);
         strncpy(host_, x.c_str(), sizeof(host_) - 1);
 
+        s >> nattrs_;
+        ASSERT(nattrs_ >= 0 && nattrs_ <= MAX_NODE_ATTRIBUTES);
+        zero(attributes_);
+        for (int i = 0; i < nattrs_; ++i) {
+            s >> x;
+            strncpy(attributes_[i], x.c_str(), sizeof(attributes_[0]) - 1);
+        }
+
         s >> port_;
 
         active_ = true;
@@ -105,7 +148,7 @@ public:
 
     bool available() const {
         static long maxNodeLastSeen = Resource<long>("maxNodeLastSeen", 60);
-        return ((::time(0) - lastSeen_) <= maxNodeLastSeen) && !offLine_;
+        return ((Clock::now() - lastSeen_) <= maxNodeLastSeen) && !offLine_;
     }
 
     void active(bool on) { active_ = on; }
@@ -125,6 +168,39 @@ public:
 
     const char* host() const { return host_; }
 
+    void attributes(const std::set<std::string>& attrs) {
+        ASSERT(attrs.size() >= 0 && attrs.size() <= MAX_NODE_ATTRIBUTES);
+        zero(attributes_);
+        nattrs_ = 0;
+        for (const auto& a : attrs) {
+            strncpy(attributes_[nattrs_++], a.c_str(), sizeof(attributes_[0])-1);
+        }
+    }
+
+    std::set<std::string> attributes() const {
+        std::set<std::string> ret;
+        for (int i = 0; i < nattrs_; ++i) {
+            ret.insert(attributes_[i]);
+        }
+        return ret;
+    }
+
+    int attributesCount() const { return nattrs_; }
+
+    bool hasAttributes(const std::set<std::string>& attributes) const {
+        for (const auto& a : attributes) {
+            bool found = false;
+            for (int i = 0; i < nattrs_; ++i) {
+                if (a == attributes_[i]) {
+                    found = true;
+                    break;
+                }
+            }
+            if (!found) return false;
+        }
+        return true;
+    }
+
     void host(const std::string& h) {
         zero(host_);
         strncpy(host_, h.c_str(), sizeof(host_) - 1);
@@ -138,9 +214,14 @@ public:
 };
 std::ostream& operator<<(std::ostream& s, const ClusterNodeEntry& d) {
     s << "ClusterNodeEntry[" << d.node_ << "," << d.type_ << "," << d.host_ << ":" << d.port_ << ","
-      << (::time(0) - d.lastSeen_) << "," << (d.available() ? "available" : "not-available") << ","
-      << (d.offLine_ ? "off" : "on") << "-line"
-      << "]";
+      << (Clock::now() - d.lastSeen_) << "," << (d.available() ? "available" : "not-available") << ","
+      << (d.offLine_ ? "off" : "on") << "-line,{";
+    bool first = true;
+    for (int i = 0; i < d.nattrs_; ++i) {
+        s << (first ? "" : ",") << d.attributes_[i];
+        first = false;
+    }
+    s << "}]";
     return s;
 }
 
@@ -152,9 +233,19 @@ typedef MappedArray<ClusterNodeEntry> NodeArray;
 static NodeArray* nodeArray = 0;
 
 static pthread_once_t once = PTHREAD_ONCE_INIT;
+static std::set<std::string> offsiteNodes_;
 
 static void init() {
     nodeArray = new NodeArray("~/etc/cluster/nodes", 1024);
+
+    EtcKeyTable config("cluster/offsite", 1);
+    if (config.exists()) {
+        for (const auto& line : config.lines()) {
+            offsiteNodes_.insert(line[0]);
+            Log::info() << "Offsite nodes [" << line[0] << "]" << std::endl;
+        }
+    }
+
 }
 
 void ClusterNodes::reset() {
@@ -192,7 +283,7 @@ void ClusterNodes::refresh(const NodeInfo& info) {
     pthread_once(&once, init);
     AutoLock<NodeArray> lock(*nodeArray);
 
-    time_t now = ::time(0);
+    time_t now = Clock::now();
 
     for (NodeArray::iterator k = nodeArray->begin(); k != nodeArray->end(); ++k) {
         if ((*k).active()) {
@@ -201,15 +292,15 @@ void ClusterNodes::refresh(const NodeInfo& info) {
                 (*k).host(info.host());
                 (*k).port(info.port());
                 (*k).offLine(false);
+                (*k).attributes(info.attributes());
                 return;
             }
         }
     }
 
     std::sort(nodeArray->begin(), nodeArray->end());
-    ClusterNodeEntry c(info.node(), info.name(), info.host(), info.port());
     ASSERT(!(*nodeArray)[0].active());
-    (*nodeArray)[0] = c;
+    (*nodeArray)[0] = ClusterNodeEntry(info);
     std::sort(nodeArray->begin(), nodeArray->end());
 }
 
@@ -217,38 +308,40 @@ NodeInfo ClusterNodes::lookUp(const std::string& type, const std::string& node)
     pthread_once(&once, init);
     AutoLock<NodeArray> lock(*nodeArray);
 
-    for (NodeArray::const_iterator k = nodeArray->begin(); k != nodeArray->end(); ++k) {
-        if ((*k).active() && type == (*k).type() && node == (*k).node()) {
-            NodeInfo info;
-            info.name((*k).type());
-            info.node((*k).node());
-            info.host((*k).host());
-            info.port((*k).port());
-            info.active(!(*k).offLine());
-            return info;
+    for (const auto& k : *nodeArray) {
+        if (k.active() && type == k.type() && node == k.node()) {
+            return k.asNodeInfo();
         }
     }
 
+    if(offsite(type, node)) {
+        throw UnexpectedState(type + "@" + node + " is offsite.");
+    }
+
+
     throw SeriousBug(std::string("Cannot find info for ") + type + "@" + node);
 }
 
-NodeInfo ClusterNodes::any(const std::string& type) {
+NodeInfo ClusterNodes::any(const std::string& type, const std::set<std::string>& attributes) {
     pthread_once(&once, init);
     AutoLock<NodeArray> lock(*nodeArray);
 
-    for (NodeArray::const_iterator k = nodeArray->begin(); k != nodeArray->end(); ++k) {
-        if ((*k).active() && (*k).available() && type == (*k).type()) {
-            NodeInfo info;
-            info.name((*k).type());
-            info.node((*k).node());
-            info.host((*k).host());
-            info.port((*k).port());
-            info.active(!(*k).offLine());
-            return info;
+    std::vector<const ClusterNodeEntry*> permitted;
+
+    for (const ClusterNodeEntry& k : *nodeArray) {
+        if (k.active() && k.available() && type == k.type()) {
+            if (k.hasAttributes(attributes)) {
+                permitted.push_back(&k);
+            }
         }
     }
 
-    throw Retry(std::string("Cannot find any node for ") + type);
+    if (permitted.empty()) {
+        throw Retry(std::string("Cannot find any node for ") + type);
+    }
+
+    int choice = random() % permitted.size();
+    return permitted[choice]->asNodeInfo();
 }
 
 bool ClusterNodes::available(const std::string& type, const std::string& node) {
@@ -263,6 +356,11 @@ bool ClusterNodes::available(const std::string& type, const std::string& node) {
     return false;
 }
 
+bool ClusterNodes::offsite(const std::string& type, const std::string& node) {
+    pthread_once(&once, init);
+    return offsiteNodes_.find(node) != offsiteNodes_.end();
+}
+
 void ClusterNodes::offLine(const NodeInfo& info) {
     pthread_once(&once, init);
     AutoLock<NodeArray> lock(*nodeArray);
@@ -313,13 +411,7 @@ std::vector<NodeInfo> ClusterNodes::all() {
     AutoLock<NodeArray> lock(*nodeArray);
     for (NodeArray::const_iterator k = nodeArray->begin(); k != nodeArray->end(); ++k) {
         if ((*k).active()) {
-            NodeInfo info;
-            info.name((*k).type());
-            info.node((*k).node());
-            info.host((*k).host());
-            info.port((*k).port());
-            info.active(!(*k).offLine());
-            result.push_back(info);
+            result.push_back(k->asNodeInfo());
         }
     }
 
