@@ -16,6 +16,7 @@
 #include "eckit/runtime/Monitor.h"
 #include "eckit/runtime/ProcessControler.h"
 #include "eckit/thread/ThreadControler.h"
+#include "eckit/io/Select.h"
 
 namespace eckit {
 namespace net {
@@ -58,17 +59,33 @@ void NetService::run() {
     Monitor::instance().name(name());
     Monitor::instance().kind(name());
 
-    Log::status() << "Waiting on port " << port() << std::endl;
+    std::ostringstream oss;
+    oss << "Waiting on port " << port();
 
     while (!stopped()) {
 
+        Log::status() << oss.str() << std::endl;
+
+        if(timeout()) {
+            Select select(server_);
+            if(!select.ready(timeout())) {
+                // This will allow to check stopped() again
+                continue;
+            }
+        }
+
+        NetUser* user = newUser(server_.accept(oss.str()));
+
         if (runAsProcess()) {
-            NetServiceProcessControler t(name(), newUser(server_.accept()), server_, Monitor::instance().self(),
+            NetServiceProcessControler t(name(),
+                                         user,
+                                         server_,
+                                         Monitor::instance().self(),
                                          visible_);
             t.start();
         }
         else {
-            ThreadControler t(newUser(server_.accept()));
+            ThreadControler t(user);
             t.start();
         }
     }
@@ -82,6 +99,10 @@ bool NetService::preferToRunAsProcess() const {
     return false;
 }
 
+long NetService::timeout() const {
+    return 0;
+}
+
 //----------------------------------------------------------------------------------------------------------------------
 
 NetServiceProcessControler::NetServiceProcessControler(const std::string& name, NetUser* user, TCPServer& server,
