@@ -26,19 +26,24 @@ static void init(SocketOptions& opts) {
 
     opts.listenBacklog(ListenBacklog);
 
-    static bool ReusePort  = eckit::Resource<bool>("socketOptionsReusePort", false);
-    static bool ReuseAddr  = eckit::Resource<bool>("socketOptionsReuseAddr", false);
-    static bool NoLinger   = eckit::Resource<bool>("socketOptionsNoLinger", false);
-    static bool KeepAlive  = eckit::Resource<bool>("socketOptionsKeepAlive", true);
-    static bool IpLowDelay = eckit::Resource<bool>("socketOptionsIpLowDelay", true);
-    static bool TcpNoDelay = eckit::Resource<bool>("socketOptionsTcpNoDelay", true);
+    static bool reusePort  = eckit::Resource<bool>("socketOptionsReusePort", false);
+    static bool reuseAddr  = eckit::Resource<bool>("socketOptionsReuseAddr", false);
+    static bool noLinger   = eckit::Resource<bool>("socketOptionsNoLinger", false);
+    static bool keepAlive  = eckit::Resource<bool>("socketOptionsKeepAlive", true);
+    static bool ipLowDelay = eckit::Resource<bool>("socketOptionsIpLowDelay", true);
+    static bool tcpNoDelay = eckit::Resource<bool>("socketOptionsTcpNoDelay", true);
 
-    opts.reusePort(ReusePort);
-    opts.reuseAddr(ReuseAddr);
-    opts.noLinger(NoLinger);
-    opts.keepAlive(KeepAlive);
-    opts.ipLowDelay(IpLowDelay);
-    opts.tcpNoDelay(TcpNoDelay);
+    static int receiveBufferSize = eckit::Resource<int>("socketOptionsReceiveBufferSize", 0);
+    static int sendBufferSize = eckit::Resource<int>("socketOptionsSendBufferSize", 0);
+
+    opts.reusePort(reusePort);
+    opts.reuseAddr(reuseAddr);
+    opts.noLinger(noLinger);
+    opts.keepAlive(keepAlive);
+    opts.ipLowDelay(ipLowDelay);
+    opts.tcpNoDelay(tcpNoDelay);
+    opts.receiveBufferSize(receiveBufferSize);
+    opts.sendBufferSize(sendBufferSize);
 }
 
 
@@ -55,7 +60,10 @@ void SocketOptions::print(std::ostream& s) const {
       << "keepAlive=" << keepAlive_ << ", "
       << "noLinger=" << noLinger_ << ", "
       << "ipLowDelay=" << ipLowDelay_ << ", "
-      << "tcpNoDelay=" << tcpNoDelay_ << "]" << std::endl;
+      << "tcpNoDelay=" << tcpNoDelay_ << ", "
+      << "receiveBufferSize=" << receiveBufferSize_ << ", "
+      << "sendBufferSize=" << sendBufferSize_ 
+      << "]" << std::endl;
 }
 
 SocketOptions SocketOptions::none() {
