@@ -17,7 +17,8 @@ namespace eckit {
 namespace net {
 
 
-Telnetable::Telnetable(int port) : telnet_(new Telnet(port)) {
+Telnetable::Telnetable(int port) :
+    telnet_(new Telnet(port)) {
     if (port != 0)
         telnet_.start();
 }
