@@ -26,6 +26,25 @@ namespace sql {
 
 class SQLDistinctOutput : public SQLOutput {
 
+    // Comparator to ensure that all cases are well defined, even if we are representing non-double
+    // data as doubles
+
+    struct DoubleBitwiseLessComparator {
+        bool operator()(const std::vector<double>& lhs, const std::vector<double>& rhs) const {
+            if (lhs.size() != rhs.size()) return lhs.size() < rhs.size();
+            for (int i = 0; i < lhs.size(); ++i) {
+                const void* p1 = &lhs[i];
+                const void* p2 = &rhs[i];
+                const uint64_t& punned1 = *reinterpret_cast<const uint64_t*>(p1);
+                const uint64_t& punned2 = *reinterpret_cast<const uint64_t*>(p2);
+                if (punned1 != punned2) {
+                    return punned1 < punned2;
+                }
+            }
+            return false;
+        }
+    };
+
 public:  // methods
     SQLDistinctOutput(SQLOutput& output);
     virtual ~SQLDistinctOutput() override;
@@ -36,7 +55,7 @@ private:  // methods
     // -- Members
 
     SQLOutput& output_;
-    std::set<std::vector<double>> seen_;
+    std::set<std::vector<double>, DoubleBitwiseLessComparator> seen_;
     std::vector<double> tmp_;
     std::vector<size_t> offsets_;
 
