@@ -17,15 +17,13 @@ namespace sql {
 namespace type {
 
 SQLBit::SQLBit(const std::string& name, unsigned long mask, unsigned long shift) :
-    type::SQLType(name),
-    mask_(mask),
-    shift_(shift) {}
+    type::SQLType(name), mask_(mask), shift_(shift) {}
 
 SQLBit::~SQLBit() {}
 
+// This is an odd one, but it allows us to store values in DISTINCT/ORDER expressions
 size_t SQLBit::size() const {
-    NOTIMP;
-    // This should not be called
+    return sizeof(long);
 }
 
 void SQLBit::output(SQLOutput& o, double x, bool missing) const {
