@@ -17,9 +17,10 @@ namespace eckit {
 namespace sql {
 namespace type {
 
-//--------------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
-SQLInt::SQLInt(const std::string& name) : SQLType(name) {}
+SQLInt::SQLInt(const std::string& name) :
+    SQLType(name) {}
 
 SQLInt::~SQLInt() {}
 
@@ -35,7 +36,7 @@ std::string SQLInt::asString(const double* val) const {
     return eckit::Translator<long, std::string>()(*val);
 }
 
-//--------------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 }  // namespace type
 }  // namespace sql
