@@ -419,7 +419,7 @@ int run_tests(int argc, char* argv[], bool initEckitMain = true) {
 
 #define CASE(description)                                                                                           \
     void UNIQUE_NAME2(test_, __LINE__)(std::string&, int&, int);                                                    \
-    static eckit::testing::TestRegister UNIQUE_NAME2(test_registration_, __LINE__)(description,                     \
+    static const eckit::testing::TestRegister UNIQUE_NAME2(test_registration_, __LINE__)(description,                     \
                                                                                    &UNIQUE_NAME2(test_, __LINE__)); \
     void UNIQUE_NAME2(test_, __LINE__)(std::string & _test_subsection, int& _num_subsections, int _subsection)
 
