@@ -12,14 +12,14 @@
 #include "eckit/thread/Thread.h"
 #include "eckit/thread/AutoLock.h"
 
-//----------------------------------------------------------------------------------------------------------------------
 
 namespace eckit {
 
 //----------------------------------------------------------------------------------------------------------------------
 
 
-Thread::Thread(bool autodel) : stop_(false), autodel_(autodel) {}
+Thread::Thread(bool autodel) :
+    stop_(false), autodel_(autodel) {}
 
 Thread::~Thread() {}
 
