@@ -63,8 +63,8 @@ void Url::parse(const std::string& url, bool param) {
             case '&':
                 if (param) {
                     dict_[Html::removeHex(p)] = Html::removeHex(s);
-                    s                        = "";
-                    p                        = "";
+                    s                         = "";
+                    p                         = "";
                 }
                 else {
                     s += url[index];
@@ -191,7 +191,8 @@ void Url::parse(std::istream& in) {
     Log::debug() << *this << std::endl;
 }
 
-Url::Url(const std::string& url) : method_("GET") {
+Url::Url(const std::string& url) :
+    method_("GET") {
     parse(url, false);
     Log::debug() << "Incomming url-> " << *this << std::endl;
 }
