@@ -27,16 +27,16 @@ namespace {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-static const std::vector<long> INTEGER_DATA{9999, 8888, 7777, 6666, 6666, 6666, 4444, 3333, 2222, 1111};
-static const std::vector<double> REAL_DATA{99.9, 88.8, 77.7, 66.6, 66.6, 88.8, 44.4, 33.3, 22.2, 11.1};
+static const std::vector<long> INTEGER_DATA{9999, 8888, 7777, 6666, 6666, 6666, 4444, 3333, 2222, 1111, 1234};
+static const std::vector<double> REAL_DATA{99.9, 88.8, 77.7, 66.6, 66.6, 88.8, 44.4, 33.3, 22.2, 11.1, 12.3};
 static const std::vector<std::string> STRING_DATA{"cccc", "a-longer-string", "cccc", "cccc",
-                                                  "cccc", "hijklmno", "aaaabbbb", "a-longer-string",
-                                                  "another-string", "another-string2"};
+                                                  "", "hijklmno", "aaaabbbb", "a-longer-string",
+                                                  "another-string", "another-string2", ""};
 
-static const std::vector<long> BITFIELD_DATA{0, 1, 2, 4, 8, 9, 10, 12, 13, 15};
-static const std::vector<long> BF1_DATA{0, 1, 0, 0, 0, 1, 0, 0, 1, 1};
-static const std::vector<long> BF2_DATA{0, 0, 1, 2, 0, 0, 1, 2, 2, 3};
-static const std::vector<long> BF3_DATA{0, 0, 0, 0, 1, 1, 1, 1, 1, 1};
+static const std::vector<long> BITFIELD_DATA{0, 1, 2, 4, 8, 9, 10, 12, 13, 15, 11};
+static const std::vector<long> BF1_DATA{0, 1, 0, 0, 0, 1, 0, 0, 1, 1, 1};
+static const std::vector<long> BF2_DATA{0, 0, 1, 2, 0, 0, 1, 2, 2, 3, 1};
+static const std::vector<long> BF3_DATA{0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1};
 
 
 class TestTable : public eckit::sql::SQLTable {
@@ -155,7 +155,6 @@ class TestOutput : public eckit::sql::SQLOutput {
         for (const auto& r : results) {
             r->output(*this);
         }
-        //        eckit::Log::info() << "..." << intOutput_ << floatOutput_ << strOutput_ << std::endl;
         return true;
     }
 
@@ -232,7 +231,6 @@ CASE("Select from constructed table") {
         EXPECT(o.intOutput == INTEGER_DATA);
         EXPECT(o.floatOutput.empty());
         EXPECT(o.strOutput == STRING_DATA);
-        eckit::Log::info() << "Column names; " << o.columnNames << std::endl;
         EXPECT(o.columnNames == std::vector<std::string>({"scol", "icol"}));
     }
 
@@ -286,6 +284,23 @@ CASE("Select from constructed table") {
         EXPECT(o.columnNames == std::vector<std::string>({"rcol"}));
     }
 
+    SECTION("Test SQL select where string is not empty") {
+
+        for (const auto& sql : {"select rcol from table1 where scol != \"\"",
+                                                  "select rcol from table1 where scol != ''"}) {
+
+            eckit::sql::SQLParser::parseString(session, sql);
+
+            session.statement().execute();
+
+            EXPECT(o.intOutput.empty());
+            std::vector<double> expected{99.9, 88.8, 77.7, 66.6, 88.8, 44.4, 33.3, 22.2, 11.1};
+            EXPECT(o.floatOutput == expected);
+            EXPECT(o.strOutput.empty());
+            EXPECT(o.columnNames == std::vector<std::string>({"rcol"}));
+        }
+    }
+
     SECTION("Test SQL select distinct") {
 
         std::vector<std::string> queries = {"select distinct icol from table1",
@@ -299,24 +314,24 @@ CASE("Select from constructed table") {
             session.statement().execute();
 
             if (i == 0) {
-                EXPECT(o.intOutput == std::vector<long>({9999, 8888, 7777, 6666, 4444, 3333, 2222, 1111}));
+                EXPECT(o.intOutput == std::vector<long>({9999, 8888, 7777, 6666, 4444, 3333, 2222, 1111, 1234}));
                 EXPECT(o.floatOutput.empty() && o.strOutput.empty());
                 EXPECT(o.columnNames == std::vector<std::string>({"icol"}));
             }
             else if (i == 1) {
-                EXPECT(o.floatOutput == std::vector<double>({99.9, 88.8, 77.7, 66.6, 44.4, 33.3, 22.2, 11.1}));
+                EXPECT(o.floatOutput == std::vector<double>({99.9, 88.8, 77.7, 66.6, 44.4, 33.3, 22.2, 11.1, 12.3}));
                 EXPECT(o.intOutput.empty() && o.strOutput.empty());
                 EXPECT(o.columnNames == std::vector<std::string>({"rcol"}));
             }
             else if (i == 2) {
-                EXPECT(o.strOutput == std::vector<std::string>({"cccc", "a-longer-string", "hijklmno", "aaaabbbb", "another-string", "another-string2"}));
+                EXPECT(o.strOutput == std::vector<std::string>({"cccc", "a-longer-string", "", "hijklmno", "aaaabbbb", "another-string", "another-string2"}));
                 EXPECT(o.intOutput.empty() && o.floatOutput.empty());
                 EXPECT(o.columnNames == std::vector<std::string>({"scol"}));
             }
             else {
                 // Test that it is finding unique rows, not values (n.b. 6666/88.8)
-                EXPECT(o.intOutput == std::vector<long>({9999, 8888, 7777, 6666, 6666, 4444, 3333, 2222, 1111}));
-                EXPECT(o.floatOutput == std::vector<double>({99.9, 88.8, 77.7, 66.6, 88.8, 44.4, 33.3, 22.2, 11.1}));
+                EXPECT(o.intOutput == std::vector<long>({9999, 8888, 7777, 6666, 6666, 4444, 3333, 2222, 1111, 1234}));
+                EXPECT(o.floatOutput == std::vector<double>({99.9, 88.8, 77.7, 66.6, 88.8, 44.4, 33.3, 22.2, 11.1, 12.3}));
                 EXPECT(o.strOutput.empty());
                 EXPECT(o.columnNames == std::vector<std::string>({"icol", "rcol"}));
             }
@@ -334,10 +349,10 @@ CASE("Select from constructed table") {
                                                                                    // contents
         };
 
-        std::vector<std::vector<long>> vals = {{1111, 2222, 3333, 4444, 6666, 6666, 6666, 7777, 8888, 9999},
-                                               {1111, 2222, 3333, 4444, 6666, 6666, 6666, 7777, 8888, 9999},
-                                               {9999, 8888, 7777, 6666, 6666, 6666, 4444, 3333, 2222, 1111},
-                                               {1111, 2222, 3333, 4444, 6666, 7777, 8888, 9999}};
+        std::vector<std::vector<long>> vals = {{1111, 1234, 2222, 3333, 4444, 6666, 6666, 6666, 7777, 8888, 9999},
+                                               {1111, 1234, 2222, 3333, 4444, 6666, 6666, 6666, 7777, 8888, 9999},
+                                               {9999, 8888, 7777, 6666, 6666, 6666, 4444, 3333, 2222, 1234, 1111},
+                                               {1111, 1234, 2222, 3333, 4444, 6666, 7777, 8888, 9999}};
 
         for (size_t i = 0; i < queries.size(); i++) {
 
@@ -351,8 +366,8 @@ CASE("Select from constructed table") {
             }
             else {
                 EXPECT(o.intOutput.empty());
-                EXPECT(o.floatOutput == std::vector<double>({88.8, 66.6, 77.7, 99.9, 11.1, 22.2, 44.4, 33.3, 88.8}));
-                EXPECT(o.strOutput == std::vector<std::string>({"hijklmno", "cccc", "cccc", "cccc", "another-string2", "another-string", "aaaabbbb", "a-longer-string", "a-longer-string"}));
+                EXPECT(o.floatOutput == std::vector<double>({88.8, 66.6, 77.7, 99.9, 11.1, 22.2, 44.4, 33.3, 88.8, 12.3, 66.6}));
+                EXPECT(o.strOutput == std::vector<std::string>({"hijklmno", "cccc", "cccc", "cccc", "another-string2", "another-string", "aaaabbbb", "a-longer-string", "a-longer-string", "", ""}));
                 EXPECT(o.columnNames == std::vector<std::string>({"rcol", "scol"}));
             }
         }
